@@ -17,7 +17,7 @@
 ;; individual file buffers persistently.
 ;;
 
-;;; Usage
+;;; Usage:
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -80,7 +80,7 @@
              (unless ,already-installed
                (auto-compression-mode 1))
              ,@body)
-         (unless (or ,already-installed)
+         (unless ,already-installed
            (auto-compression-mode -1))
          ;; Restore the initial state (even if it's inconsistent).
          (setq auto-compression-mode ,already-installed-value)))))
@@ -118,7 +118,7 @@ The returned path must use the extension argument."
 
 (defcustom undo-fu-session-temp-directories
   (cond
-   ((memq system-type (list 'ms-dos 'windows-nt))
+   ((memq system-type '(ms-dos windows-nt))
     (list))
    (t
     (list "/tmp" "/dev/shm")))
@@ -152,7 +152,7 @@ to convert existing files to the newly selected format."
   "Number of files to store, nil to disable limiting entirely.
 
 Enforcing removes the oldest files."
-  :type 'integer)
+  :type '(choice (const :tag "Unlimited" nil) integer))
 
 
 ;; ---------------------------------------------------------------------------
@@ -371,7 +371,7 @@ INDEX-STEP are used as keys mapping to LIST elements."
 
 (defun undo-fu-session--equivtable-encode (equiv-table buffer-list pending-list)
   "Convert the EQUIV-TABLE into an alist of buffer list indices.
-Argument BUFFER-LIST typically `undo-buffer-list'.
+Argument BUFFER-LIST typically `buffer-undo-list'.
 Argument PENDING-LIST typically `pending-undo-list'."
   (declare (important-return-value t) (side-effect-free error-free))
 
@@ -385,22 +385,21 @@ Argument PENDING-LIST typically `pending-undo-list'."
 
     (maphash
      (lambda (key val)
-       (let ((key-num (gethash key step-to-index-hash))
-             (val-num
-              (cond
-               ((eq t val)
-                t)
-               (t
-                (gethash val step-to-index-hash)))))
-         (when (and key-num val-num)
-           (push (cons key-num val-num) equiv-table-alist))))
+       (when-let* ((key-num (gethash key step-to-index-hash))
+                   (val-num
+                    (cond
+                     ((eq t val)
+                      t)
+                     (t
+                      (gethash val step-to-index-hash)))))
+         (push (cons key-num val-num) equiv-table-alist)))
      equiv-table)
     equiv-table-alist))
 
 
 (defun undo-fu-session--equivtable-decode (equiv-table-alist buffer-list pending-list)
   "Convert EQUIV-TABLE-ALIST into a hash compatible with `undo-equiv-table'.
-Argument BUFFER-LIST an `undo-buffer-list' compatible list.
+Argument BUFFER-LIST a `buffer-undo-list' compatible list.
 Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
@@ -541,11 +540,8 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
   (cond
-   ((symbolp undo-fu-session-compression)
+   (undo-fu-session-compression
     (concat "." (symbol-name undo-fu-session-compression)))
-   ((eq undo-fu-session-compression t)
-    ;; Used for older versions where compression was a boolean.
-    ".gz")
    (t
     ".el")))
 
@@ -562,7 +558,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
        (undo-fu-session-make-file-name filename ext)))))
 
 (defun undo-fu-session-make-file-name (filename ext)
-  "Take the path FILENAME, EXT and return a name base on this."
+  "Take the path FILENAME and EXT, returning a name based on them."
   (declare (important-return-value t) (side-effect-free error-free))
   (concat
    (file-name-concat undo-fu-session-directory
@@ -901,7 +897,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   (when (and
          ;; Not already enabled.
-         (null (bound-and-true-p undo-fu-session-mode))
+         (not (bound-and-true-p undo-fu-session-mode))
          ;; Not in the mini-buffer.
          (null (minibufferp))
          ;; Not a special mode (package list, tabulated data ... etc)
